==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/colorsel.cc <==
// $Id: colorsel.cc,v 1.13 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "box.hh"

class Gtk_ColorSelection : public Gtk_VBox 
{public:
	typedef Gtk_VBox Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_ColorSelection();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_ColorSelection Gtk_ColorSelection;

const std::string Gtk_ColorSelection::TypeName(const Widget &w) const
{  return GtkPrefix()+"ColorSelection";
}

const std::string Gtk_ColorSelection::IncludeName(const Widget &w) const
{  return "gtk--/colorsel.h";
}

Gtk_ColorSelection::Gtk_ColorSelection()
{  Writer["GtkColorSelection"]=this;
}

//#warning this code is untested

#include "window.hh"

class Gtk_ColorSelectionDialog : public Gtk_Window 
{public:
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_ColorSelectionDialog();
};

static Gtk_ColorSelectionDialog Gtk_ColorSelectionDialog;

const std::string Gtk_ColorSelectionDialog::TypeName(const Widget &w) const
{  return GtkPrefix()+"ColorSelectionDialog";
}

const std::string Gtk_ColorSelectionDialog::IncludeName(const Widget &w) const
{  return "gtk--/colorsel.h";
}

Gtk_ColorSelectionDialog::Gtk_ColorSelectionDialog()
{  Writer["GtkColorSelectionDialog"]=this;
}

//#warning this code is untested

==> glademm_2.6.0.orig.tar.gz: glademm-2.6.0/src/writers/colorsel.cc <==
// $Id: colorsel.cc,v 1.17 2002/07/18 14:08:43 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "box.hh"

class Gtk_ColorSelection : public Gtk_VBox 
{public:
	typedef Gtk_VBox Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_ColorSelection();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_ColorSelection Gtk_ColorSelection;

const std::string Gtk_ColorSelection::TypeName(const Widget &w) const
{  return GtkPrefix()+"ColorSelection";
}

const std::string Gtk_ColorSelection::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"colorselection.h";
}

Gtk_ColorSelection::Gtk_ColorSelection()
{  Writer["GtkColorSelection"]=this;
}

//#warning this code is untested

#include "window.hh"

class Gtk_ColorSelectionDialog : public Gtk_Window 
{public:
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_ColorSelectionDialog();
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const;
};

static Gtk_ColorSelectionDialog Gtk_ColorSelectionDialog;

const std::string Gtk_ColorSelectionDialog::TypeName(const Widget &w) const
{  return GtkPrefix()+"ColorSelectionDialog";
}

const std::string Gtk_ColorSelectionDialog::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"colorselection.h";
}

Gtk_ColorSelectionDialog::Gtk_ColorSelectionDialog()
{  Writer["GtkColorSelectionDialog"]=this;
}

void Gtk_ColorSelectionDialog::ConstructionArgs(const Widget &w, CxxFile &f) const
{  const std::string title=w.getProperty("title");
   f.FunctionArg() << Configuration.Translatable(title);
}

//#warning this code is untested
